import { IOptions } from '../interfaces/ioptions';
import * as i0 from "@angular/core";
/**
 * Service for managing custom notifications in the application.
 * This service provides methods to show different types of notifications
 * (success, warning, error, info) and allows for customization of the notification options.
 */
export declare class CustomNotificationService {
    private notificationSubject;
    notification$: import("rxjs").Observable<{
        message: string;
        options: IOptions;
    }>;
    /**
     * Displays a notification with the specified message and options.
     * Clears any existing notifications before showing the new one.
     *
     * @param {string} message - The message to display in the notification.
     * @param {IOptions} [options=this.defaultOptions()] - The options for customizing the notification.
     */
    show(message: string, options?: IOptions): void;
    /**
     * Displays a success notification.
     *
     * @param {string} message - The message to display in the success notification.
     * @param {IOptions} [options=this.defaultOptions()] - The options for customizing the success notification.
     */
    success(message: string, options?: IOptions): void;
    /**
     * Displays a warning notification.
     *
     * @param {string} message - The message to display in the warning notification.
     * @param {IOptions} [options=this.defaultOptions()] - The options for customizing the warning notification.
     */
    warning(message: string, options?: IOptions): void;
    /**
     * Displays an error notification.
     *
     * @param {string} message - The message to display in the error notification.
     * @param {IOptions} [options=this.defaultOptions()] - The options for customizing the error notification.
     */
    error(message: string, options?: IOptions): void;
    /**
     * Displays an info notification.
     *
     * @param {string} message - The message to display in the info notification.
     * @param {IOptions} [options=this.defaultOptions()] - The options for customizing the info notification.
     */
    info(message: string, options?: IOptions): void;
    /**
     * Clears any existing notifications.
     */
    clear(): void;
    /**
     * Provides default options for notifications.
     *
     * @returns {IOptions} - An object containing default values for type, title, duration, and position of notifications.
     */
    defaultOptions(): IOptions;
    static ɵfac: i0.ɵɵFactoryDeclaration<CustomNotificationService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<CustomNotificationService>;
}
